@@ -5,5 +5,5 @@
 void
 symmetrizer_prod(double *a, int *lda, int *arow, int *acol, double *b, int *ldb)
 { /* computes: B <- N %*% A or B <- A %*% N */
-  add_mat(a, *lda, 0.5, b, *ldb, *arow, *acol);
+  FM_add_mat(a, *lda, 0.5, b, *ldb, *arow, *acol);
 }
